@@ -6,7 +6,7 @@ yield.scaled <- wheat$yield * sqrt(3/1000)
 treatment <- factor(paste(wheat$tillage, wheat$summerCrop, wheat$manure,
                           wheat$N, sep = ""))
 bilinear3 <- gnm(yield.scaled ~ year + treatment +
-                 Mult(year, treatment, multiplicity = 3),
+                 instances(Mult(year, treatment), 3),
                  family = gaussian, data = wheat)
 
 print(bilinear3$deviance, digits=10)
